@@ -7,7 +7,7 @@
  * Description : digiKam 8/16 bits image management API
  *
  * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2020 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -405,7 +405,7 @@ public:
     /**
      * When saving, several changes to the image metadata are necessary
      * before it can safely be written to the new file.
-     * This method updates the stored DMetadata object in preparation to a subsequent
+     * This method updates the stored meta engine object in preparation to a subsequent
      * call to save() with the same target file.
      * 'intendedDestPath' is the finally intended file name. Do not give the temporary
      *   file name if you are going to save() to a temp file.
@@ -760,7 +760,7 @@ public:
 
 private:
 
-    DImg(const DImg& image, int w, int h);
+    DImg(const DImg& image, uint w, uint h);
 
     void copyMetaData(const QExplicitlySharedDataPointer<Private>& src);
     void copyImageData(const QExplicitlySharedDataPointer<Private>& src);
@@ -770,10 +770,10 @@ private:
 
     bool clipped(int& x, int& y, int& w, int& h, uint width, uint height) const;
 
-    QDateTime  creationDateFromFilesystem(const QFileInfo& fileInfo) const;
+    QDateTime         creationDateFromFilesystem(const QFileInfo& fileInfo) const;
 
-    QByteArray createUniqueHash(const QString& filePath, const QByteArray& ba) const;
-    QByteArray createUniqueHashV2(const QString& filePath) const;
+    static QByteArray createUniqueHash(const QString& filePath, const QByteArray& ba);
+    static QByteArray createUniqueHashV2(const QString& filePath);
 
     void bitBlt(const uchar* const src, uchar* const dest,
                 int sx, int sy, int w, int h, int dx, int dy,
