@@ -10,9 +10,9 @@
  *               Iptc : https://www.iptc.org/std/IIM/4.1/specification/IIMV4.1.pdf
  *               Xmp  : https://www.adobe.com/devnet/xmp/pdfs/xmp_specification.pdf
  *                      https://www.iptc.org/std/Iptc4xmpCore/1.0/specification/Iptc4xmpCore_1.0-spec-XMPSchema_8.pdf
- *               Paper: http://www.metadataworkinggroup.com/pdf/mwg_guidance.pdf
+ *               Paper: www.metadataworkinggroup.com/pdf/mwg_guidance.pdf
  *
- * Copyright (C) 2006-2020 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -52,6 +52,8 @@
 namespace Digikam
 {
 
+// TODO: merge with DMetadata class.
+
 class DIGIKAM_EXPORT MetaEngine
 {
 
@@ -160,7 +162,7 @@ public:
     /**
      * Standard destructor
      */
-    virtual ~MetaEngine();
+    ~MetaEngine();
 
     /**
      * Create a copy of container
@@ -176,24 +178,24 @@ public:
     /**
      * Return true if Exiv2 library initialization is done properly.
      * This method must be called before using libMetaEngine with multithreading.
-     * It initialize several non re-entrancy code from Adobe XMP SDK
-     * See Bug #166424 for details. Call cleanupExiv2() to clean things up later.
+     * It initialize several non re-entrancy code from Adobe XMP SDK, and register
+     * a function to cleanup automatically all XMP SDK memory allocation.
+     * See Bug #166424 for details.
      */
     static bool initializeExiv2();
 
     /**
-     * Return true if Exiv2 library memory allocations are cleaned properly.
-     * This method must be called after using libMetaEngine with multithreading.
-     * It cleans up memory used by Adobe XMP SDK
-     * See Bug #166424 for details.
-     */
-    static bool cleanupExiv2();
-
-    /**
-     * Return true if library can handle Xmp metadata
+     * Return true if Exiv2 library is compiled with Xmp metadata support.
      */
     static bool supportXmp();
 
+    /**
+     * Return true if library support Base Media File Format (aka CR3, HEIF, HEIC, and AVIF).
+     * Note: use this function only after to call initializeExiv2(), else false will aways returned.
+     * The function return true only if Exiv2 >= 0.27.4 compiled with BMFF support.
+     */
+    static bool supportBmff();
+
     /**
      * Return true if library can write metadata to typeMime file format.
      */
@@ -355,7 +357,7 @@ public:
      * Load all metadata (Exif, Iptc, Xmp, and JFIF Comments) from a picture (JPEG, RAW, TIFF, PNG,
      * DNG, etc...). Return true if metadata have been loaded successfully from file.
      */
-    virtual bool load(const QString& filePath);
+    bool load(const QString& filePath);
 
     /**
      * Load metadata from a sidecar file and merge.
@@ -455,7 +457,7 @@ public:
      * Re-implement this method if you want to use another item file format than JPEG to
      * save preview.
      */
-    virtual bool setItemPreview(const QImage& preview) const;
+    bool setItemPreview(const QImage& preview) const;
 
     //@}
 
